@@ -8,16 +8,16 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = 1.27;
+our $VERSION = 1.29;
 
 use MooseX::App::Meta::Role::Attribute::Option;
-use MooseX::App::Exporter qw(app_base app_fuzzy app_strict app_prefer_commandline option parameter);
+use MooseX::App::Exporter qw(app_usage app_description app_base app_fuzzy app_strict app_prefer_commandline option parameter);
 use MooseX::App::Message::Envelope;
 use Moose::Exporter;
 use Scalar::Util qw(blessed);
 
 my ($IMPORT,$UNIMPORT,$INIT_META) = Moose::Exporter->build_import_methods(
-    with_meta           => [ qw(app_namespace app_base app_fuzzy app_command_name app_strict option parameter) ],
+    with_meta           => [ qw(app_usage app_description app_namespace app_base app_fuzzy app_command_name app_strict option parameter) ],
     also                => [ 'Moose' ],
     as_is               => [ 'new_with_command' ],
     install             => [ 'unimport','init_meta' ],
@@ -41,7 +41,10 @@ sub init_meta {
     
     $args{roles}        = ['MooseX::App::Role::Base'];
     $args{metaroles}    = {
-        class               => ['MooseX::App::Meta::Role::Class::Base'],
+        class               => [
+            'MooseX::App::Meta::Role::Class::Base',
+            'MooseX::App::Meta::Role::Class::Documentation'
+        ],
         attribute           => ['MooseX::App::Meta::Role::Attribute::Option'],
     };
     
@@ -65,9 +68,11 @@ sub new_with_command {
         if ! defined $class || blessed($class);
     
     my $meta = $class->meta;
-
-    Moose->throw_error('new_with_command may only be called from the application base package')
-        if $meta->meta->does_role('MooseX::App::Meta::Role::Class::Command');
+    my $metameta = $meta->meta;
+    # TODO Fix this check
+    Moose->throw_error('new_with_command may only be called from the application base package:'.$class.'->'.$meta)
+        if $metameta->does_role('MooseX::App::Meta::Role::Class::Command')
+        || ! $metameta->does_role('MooseX::App::Meta::Role::Class::Base');
         
     # Extra args
     my %args;
@@ -225,15 +230,17 @@ MooseX-App will then
 
 =over
 
-=item * Find, load and initialise the command classes
+=item * Find, load and initialise the command classes (see L<MooseX-App-Simple>
+for single command applications)
 
 =item * Create automated help and documentation from modules POD and 
 attributes metadata
 
 =item * Read, encode and validate the command line options and positional 
-parameters entered by the user from @ARGV
+parameters entered by the user from @ARGV (and possibly %ENV)
 
-=item * Provide helpful error messages if user input cannot be validated
+=item * Provide helpful error messages if user input cannot be validated (
+either missing or wrong attributes or Moose type constraints not satisfied)
 
 =back
 
@@ -279,25 +286,25 @@ MooseX::App command line application.
 
  my $myapp_command = MyApp->new_with_command();
 
-This method reads the command line arguments from the user and tries to create
-a command object. If it fails it retuns a L<MooseX::App::Message::Envelope> 
-object holding an error message.
+This constructor reads the command line arguments and tries to create a 
+command class instance. If it fails it retuns a 
+L<MooseX::App::Message::Envelope> object holding an error message.
 
-You can pass a hash of default params to new_with_command
+You can pass a hash of default/fallback params to new_with_command
 
- MyApp->new_with_command(%default);
+ my $obj = MyApp->new_with_command(%default);
 
 =head2 initialize_command_class
 
- my $myapp_command = MyApp->initialize_command_class($command_name,%default);
+ my $obj = MyApp->initialize_command_class($command_name,%default);
 
-Helper method to initialize the command class for the given command.
+Helper method to instantiate the command class for the given command.
 
 =head1 GLOBAL OPTIONS
 
 =head2 app_base
 
- app_base 'my_script';
+ app_base 'my_script'; # Defaults to $0
 
 Usually MooseX::App will take the name of the calling wrapper script to 
 construct the program name in various help messages. This name can 
@@ -309,7 +316,7 @@ be changed via the app_base function.
 
 Usually MooseX::App will take the package name of the base class as the 
 namespace for commands. This namespace can be changed and you can add
-several other namespaces.
+multiple extra namespaces.
 
 =head2 app_fuzzy
 
@@ -343,13 +350,25 @@ individually for each command.
 This sub can be used to control how package names should be translated
 to command names.
 
+=head2 app_description
+
+Set the description. If not set this information will be taken from the
+Pod DESCRIPTION or OVERVIEW sections.
+
+=head2 app_usage
+
+Set custom usage. If not set this will be taken from the Pod SYNOPSIS or 
+USAGE section. If those sections are not available, the usage
+information will be autogenerated.
+
 =head1 GLOBAL ATTRIBUTES
 
-All MooseX::App classes will have two extra attributes/accessors
+All MooseX::App classes will have two extra attributes
 
 =head2 extra_argv
 
-Carries all parameters from @ARGV that were not consumed.
+Carries all parameters from @ARGV that were not consumed (only if app_strict
+is turned off, otherwise superfluous parameters will raise an exception).
 
 =head2 help_flag
 
@@ -374,6 +393,28 @@ Help flag that is set when help was requested.
 Refer to L<MooseX::App::Meta::Role::Attribute::Option> for detailed 
 documentation.
 
+=head1 METADATA
+
+MooseX::App will use your class metadata and POD to construct the commands and
+helpful error- or usage- messages. These bits of information are utilised 
+and should be provided if possible:
+
+=over
+
+=item * Package names
+
+=item * L<required> options for Moose attributes
+
+=item * L<documentation> options for Moose attributes
+
+=item * Moose type constraints (Bool, ArrayRef, HashRef, Int, Num, and Enum)
+
+=item * POD (NAME, ABSTRACT, DESCRIPTION, USAGE, SYNOPSIS and OVERVIEW sections)
+
+=item * Dzil ABSTRACT tag if no POD is available yet
+
+=back
+
 =head1 PLUGINS
 
 The behaviour of MooseX-App can be customised with plugins. To load a
@@ -381,9 +422,6 @@ plugin just pass a list of plugin names after the C<use MooseX-App> statement.
 
  use MooseX::App qw(PluginA PluginB);
 
-Read the L<Writing MooseX-App Plugins|MooseX::App::WritingPlugins> 
-documentation on how to create your own plugins.
-
 Currently the following plugins are shipped with MooseX::App
 
 =over
@@ -422,6 +460,9 @@ Display full manpage
 
 =back
 
+Refer to L<Writing MooseX-App Plugins|MooseX::App::WritingPlugins> 
+for documentation on how to create your own plugins.
+
 =head1 CAVEATS & KNOWN BUGS
 
 Startup time may be an issue. If you do not require plugins and ability for
