@@ -5,13 +5,14 @@ package MooseX::App::Meta::Role::Class::Base;
 use utf8;
 use 5.010;
 
+use List::Util qw(max);
+
 use namespace::autoclean;
 use Moose::Role;
 
 use MooseX::App::Utils;
 use Path::Class;
 use Module::Pluggable::Object;
-use List::Util qw(max);
 no if $] >= 5.018000, warnings => qw(experimental::smartmatch);
 
 has 'app_messageclass' => (
@@ -126,14 +127,44 @@ sub command_args {
     my @attributes_option  = $self->command_usage_attributes($metaclass,'option');
     
     my ($return,$errors) = $self->command_parse_options(\@attributes_option);
-    
+
+    my %raw_error;
     foreach my $option ($parsed_argv->available('option')) {
-        unshift(@{$errors},
-            $self->command_message(
+        my $key = $option->key;
+        my $raw = $option->original;
+        my $message;
+        next
+            if defined $raw_error{$raw};
+        
+        if (length $key == 1
+            && $raw =~ m/^-(\w+)$/) {
+            POSSIBLE_ATTRIBUTES:
+            foreach my $attribute ($self->command_usage_attributes($metaclass,[qw(option proto)])) {
+                foreach my $name ($attribute->cmd_name_possible) {
+                    # TODO fuzzy match
+                    if ($name eq $1) {
+                        $raw_error{$raw} = 1;
+                        $message = "Did you mean '--$name'?";
+                        last POSSIBLE_ATTRIBUTES;
+                    }
+                }
+            }
+        }
+        
+        my $error;
+        if (defined $message) {
+            $error = $self->command_message(
+                header          => "Unknown option '".$raw."'", # LOCALIZE
+                body            => $message,
+                type            => "error",
+            );
+        } else {
+            $error = $self->command_message(
                 header          => "Unknown option '".$option->key."'", # LOCALIZE
                 type            => "error",
-            )
-        );
+            );
+        }
+        unshift(@{$errors},$error);
     }
     
     # Process params
@@ -369,20 +400,20 @@ sub command_check_attribute {
     unless ($type_constraint->check($value)) {
         my $message;
         
+        if (ref($value) eq 'ARRAY') {
+            $value = join(', ',@$value);
+        } elsif (ref($value) eq 'HASH') {
+            $value = join(', ',map { $_.'='.$value->{$_} } keys %$value)
+        }
+        
         # We have a custom message
         if ($type_constraint->has_message) {
             $message = $type_constraint->get_message($value);
         # No message
         } else {
-            my $type_human = $self->command_type_constraint_description($type_constraint->name);
-            if (defined $type_human) { 
-                $message = "Value must be "; # LOCALIZE
-                if ($type_human =~ /^[aeiouy]/) {
-                    $message .= "an $type_human";
-                } else {
-                    $message .= "a $type_human";
-                }
-                $message .= " (not '$value')";
+            my $message_human = $self->command_type_constraint_description($type_constraint);
+            if (defined $message_human) {
+                $message = "Value must be ". $message_human ." (not '$value')";
             } else {
                 $message = $type_constraint->get_message($value);
             }
@@ -400,29 +431,60 @@ sub command_check_attribute {
 
 
 sub command_type_constraint_description {
-    my ($self,$type_constraint_name) = @_;
+    my ($self,$type_constraint,$singular) = @_;
     
-    given ($type_constraint_name) {
-        when ('Int') {
-            return 'integer'; # LOCALIZE
-        }
-        when ('Num') {
-            return 'number'; # LOCALIZE
-        }
-        when (/^ArrayRef\[(.*)\]$/) {
-            return $self->command_type_constraint_description($1);
-        }
-        when ('HashRef') {
-            return 'key-value pairs'; # LOCALIZE
-        } 
-        when (/^HashRef\[(.+)\]$/) {
-            return 'key-value pairs with '.$self->command_type_constraint_description($1).' values'; # LOCALIZE
-        }
-        when ('Str') {
-            return 'string'; # LOCALIZE
+    $singular //= 1;
+    
+    if ($type_constraint->isa('Moose::Meta::TypeConstraint::Enum')) {
+        return 'one of these values: '.join(', ',@{$type_constraint->values});
+    } elsif ($type_constraint->isa('Moose::Meta::TypeConstraint::Parameterized')) {
+        my $from = $type_constraint->parameterized_from;
+        if ($from->is_a_type_of('ArrayRef')) {
+            return $self->command_type_constraint_description($type_constraint->type_parameter);
+        } elsif ($from->is_a_type_of('HashRef')) {
+            return 'key-value pairs of '.$self->command_type_constraint_description($type_constraint->type_parameter,0);
         }
+    # TODO union
+    } elsif ($type_constraint->equals('Int')) {
+        return $singular ? 'an integer':'integers'; # LOCALIZE
+    } elsif ($type_constraint->equals('Num')) {
+        return $singular ? 'a number':'numbers'; # LOCALIZE
+    } elsif ($type_constraint->equals('Str')) {
+        return $singular ? 'a string':'strings';
+    } elsif ($type_constraint->equals('HashRef')) {
+        return 'key-value pairs'; # LOCALIZE
     }
     
+    if ($type_constraint->has_parent) {
+        return $self->command_type_constraint_description($type_constraint->parent);
+    }
+    
+    return;
+    
+#    given ($type_constraint_name) {
+#        when ('Int') {
+#            return 'integer'; # LOCALIZE
+#        }
+#        when ('Num') {
+#            
+#        }
+#        when (/^ArrayRef\[(.*)\]$/) {
+#            return $self->command_type_constraint_description($1);
+#        }
+#        when ('HashRef') {
+#            return 'key-value pairs'; # LOCALIZE
+#        } 
+#        when (/^HashRef\[(.+)\]$/) {
+#            return 'key-value pairs with '.$self->command_type_constraint_description($1).' values'; # LOCALIZE
+#        }
+#        when ('Str') {
+#            return 'string'; # LOCALIZE
+#        }
+#        default {
+#            $type_constraint
+#        }
+#    }
+    
     return;
 }
 
@@ -703,7 +765,7 @@ sub command_usage_command {
     
     my @usage;
     push(@usage,$self->command_usage_header($command_meta_class));
-    push(@usage,$self->command_usage_description($command_meta_class,)); 
+    push(@usage,$self->command_usage_description($command_meta_class)); 
     push(@usage,$self->command_usage_parameters($command_meta_class,'parameters:')); # LOCALIZE
     push(@usage,$self->command_usage_options($command_meta_class,'options:')); # LOCALIZE
     
@@ -720,21 +782,25 @@ sub command_usage_global {
     
     while (my ($command,$class) = each %$commands) {
         Class::Load::load_class($class);
-        my $description;
-        $description = $class->meta->command_short_description
+        my $command_description;
+        $command_description = $class->meta->command_short_description
             if $class->meta->can('command_short_description');
         
-        $description ||= '';
-        push(@commands,[$command,$description]);
+        $command_description ||= '';
+        push(@commands,[$command,$command_description]);
     }
     
     @commands = sort { $a->[0] cmp $b->[0] } @commands;
     
     my @usage;
-    push (@usage,$self->command_usage_header());
+    push(@usage,$self->command_usage_header());
+    
+    my $description = $self->command_usage_description($self);
+    push(@usage,$description)
+        if $description;
     push(@usage,$self->command_usage_parameters($self,'global parameters:')); # LOCALIZE
-    push (@usage,$self->command_usage_options($self,'global options:')); # LOCALIZE
-    push (@usage,
+    push(@usage,$self->command_usage_options($self,'global options:')); # LOCALIZE
+    push(@usage,
         $self->command_message(
             header  => 'available commands:', # LOCALIZE
             body    => MooseX::App::Utils::format_list(@commands),
