@@ -16,7 +16,6 @@ sub plugin_metaroles {
     }
 }
 
-
 1;
 
 __END__
@@ -37,8 +36,10 @@ In your base class:
 In your shell
 
  bash$ myapp pusl
- Unknown command 'psul'
- Did you mean myapp pull, myapp push?
+ Ambiguous command 'pusl'
+ Which command did you mean?
+ * push
+ * pull
 
 =head1 DESCRIPTION
 
