@@ -1,6 +1,7 @@
 package Test03::AnotherCommand;
 
 use MooseX::App::Command;
+extends qw(Test03CommandBase);
 
 use Moose::Util::TypeConstraints;
 
@@ -44,6 +45,12 @@ option 'custom2' => (
     coerce        => 1,
 );
 
+option 'split' => (
+    is            => 'rw',
+    isa           => 'ArrayRef[Str]',
+    cmd_split     => qr/;/i,
+);
+
 option ['extra1','extra2'] => (
     is            => 'rw',
 );
